@@ -52,12 +52,12 @@
 # ugh, terrible name
 # percentiles of cumulative precipitation plot
 # x: result from CDECquery for now, will need to generalize to other sources
-# this.year: current year
+# this.year: a single water year
 # method: exemplar|daily
 # q.color
 # c.color
 # ...: further arguments to plot()
-PCP_plot <- function(x, this.year=2019, method='exemplar', q.color='RoyalBlue', c.color='firebrick', ...) {
+PCP_plot <- function(x, this.year, method='exemplar', q.color='RoyalBlue', c.color='firebrick', ...) {
   
   # hack for R CMD check
   cumulative_ppt <- NULL
@@ -71,7 +71,12 @@ PCP_plot <- function(x, this.year=2019, method='exemplar', q.color='RoyalBlue',
   
   # convenience objects for plotting 
   exemplar.yrs <- as.numeric(names(e))
-  this.year.data <- xx[xx$water_year == this.year, ]
+  this.year.data <- xx[which(xx$water_year == this.year), ]
+  
+  # remove current / future years
+  xx <- xx[which(xx$water_year < this.year), ]
+  
+  ## TODO: remove years with less than 330 (?) days of data
   
   # current year positional elements
   # last real date in series
@@ -81,6 +86,11 @@ PCP_plot <- function(x, this.year=2019, method='exemplar', q.color='RoyalBlue',
   # last cumulative PPT in series
   mcp <- max(this.year.data$cumulative_ppt, na.rm = TRUE)
   
+  # water-day stats with PPT < 0.1
+  dry.wd <- xx$water_day[xx$cumulative_ppt < 0.1]
+  dry.wd.q <- quantile(dry.wd, probs = c(0.05, 0.25, 0.5, 0.75, 0.95), na.rm = TRUE)
+  
+  # PPT stats on current water-day
   this.wd.data <- xx$cumulative_ppt[xx$water_day == mwd]
   this.wd.data.q <- quantile(this.wd.data, probs = c(0.05, 0.25, 0.5, 0.75, 0.95), na.rm = TRUE)
   
@@ -139,29 +149,40 @@ PCP_plot <- function(x, this.year=2019, method='exemplar', q.color='RoyalBlue',
   text(x = 362, y=e, labels = txt, pos=4, cex=0.65, font=2)
   # text(x = 370, y=e+2, labels = , adj = c(0,0), cex=0.65, font=2)
   
-  # add percentiles for current water day via boxplot
-  # create data needed by bxp()
-  bxp.data <- list(stats=matrix(this.wd.data.q, ncol=1), n=length(this.wd.data), out=NULL, group=1, names="")
-  # add to current plot
-  bxp(bxp.data, at=0, add=TRUE, show.names=FALSE, outline = FALSE, axes = FALSE, boxwex=10, border=c.color)
-  # annotate with customized quantiles
-  text(x=0, y=this.wd.data.q, labels = names(this.wd.data.q), cex=0.65, pos=2, col=c.color)
-  
-  # annotate current year
+  # add current year's cumulative PPT
   points(x=mwd, y=mcp, pch=22, bg=c.color)
-  text(x=0, y=mcp, labels = round(mcp, 1), col=c.color, font=2, cex=0.75, pos=4)
+  
+  # add boxplot of starting water-day where cumulative PPT > 0.1
+  bxp.data <- list(stats=matrix(dry.wd.q, ncol=1), n=length(dry.wd.q), out=NULL, group=1, names="")
+  # add to current plot
+  bxp(bxp.data, at=-1, add=TRUE, show.names=FALSE, outline = FALSE, axes = FALSE, boxwex=2, border=q.color, horizontal = TRUE)
+  
+  # add box plot of cumulative PPT on current water-day
+  if(mcp > 0) {
+    # add percentiles for current water day via boxplot
+    # create data needed by bxp()
+    bxp.data <- list(stats=matrix(this.wd.data.q, ncol=1), n=length(this.wd.data), out=NULL, group=1, names="")
+    # add to current plot
+    bxp(bxp.data, at=0, add=TRUE, show.names=FALSE, outline = FALSE, axes = FALSE, boxwex=10, border=c.color)
+    # annotate with customized quantiles
+    text(x=0, y=this.wd.data.q, labels = names(this.wd.data.q), cex=0.65, pos=2, col=c.color)
+    
+    # annotate with current cumulative PPT
+    text(x=0, y=mcp, labels = round(mcp, 1), col=c.color, font=2, cex=0.75, pos=4)
+  }
+  
   
   # helper lines confusing if last water day < ~ 25
   if(mwd > 25) {
     # helper lines confusing if last cumulative PPT < 1
     if(mcp > 0) {
       # helper lines
-      segments(x0 = 25, y0 = mcp, x1 = mwd, y1 = mcp, col = alpha(c.color, 0.5))
+      segments(x0 = 20, y0 = mcp, x1 = mwd, y1 = mcp, col = alpha(c.color, 0.5))
       segments(x0 = mwd, y0 = mcp, x1 = mwd, y1 = 1, col = alpha(c.color, 0.5))
     }
     
     # annotate current (real) date
-    text(x=mwd, y=-2, labels = mrd, font=2, cex=0.75, col=c.color)  
+    text(x=mwd, y=-2.25, labels = mrd, font=2, cex=0.75, col=c.color)  
   }
   
   # basic legend
