@@ -1,11 +1,12 @@
 ## TODO: return clustering object instead of cluster$order
+## TODO: provide examples for adjusting legend size / spacing
 
 # still testing "hydrologic" order
 vizHillslopePosition <- function(x, s=NULL) {
   
   # check for required packages
-  if(!requireNamespace('dendextend', quietly=TRUE))
-    stop('please install the `dendextend` packages', call.=FALSE)
+  if(!requireNamespace('dendextend', quietly=TRUE) | !requireNamespace('latticeExtra', quietly=TRUE))
+    stop('please install the `dendextend` and `latticeExtra` packages', call.=FALSE)
   
   # CRAN CHECK hack
   hillslope_position <- NULL
@@ -52,8 +53,8 @@ vizHillslopePosition <- function(x, s=NULL) {
   pp <- barchart(series ~ value, groups=hillslope_position, data=x.long, horiz=TRUE, stack=TRUE, 
                  xlab='Proportion', 
                  scales=list(cex=1), 
-                 key=simpleKey(space='top', columns=5, text=levels(x.long$hillslope_position), rectangles = TRUE, points=FALSE), 
-                 legend=list(right=list(fun=dendrogramGrob, args=list(x = as.dendrogram(x.d.hydro), side="right", size=10))), 
+                 key=simpleKey(space='top', columns=5, text=levels(x.long$hillslope_position), rectangles = TRUE, points=FALSE, between.columns=2, between=1, cex=0.75), 
+                 legend=list(right=list(fun=latticeExtra::dendrogramGrob, args=list(x = as.dendrogram(x.d.hydro), side="right", size=10))), 
                  yscale.components=function(..., s.to.bold=s) {
                    temp <- yscale.components.default(...) 
                    
